@@ -92,44 +92,32 @@ void KGlobalSettingsTest::testPaletteChange()
 {
     CREATE_ALL_SPYS;
     callClient("-p", SIGNAL(kdisplayPaletteChanged()));
-#if QT_VERSION <= QT_VERSION_CHECK(5, 0, 0)
-    qDebug() << "The port to Qt5 native event filters broke KXMessages for Qt4, test disabled";
-#else
     QCOMPARE(palette_spy.size(), 1);
     QCOMPARE(font_spy.size(), 0);
     QCOMPARE(style_spy.size(), 0);
     QCOMPARE(settings_spy.size(), 0);
     QCOMPARE(appearance_spy.size(), 1);
-#endif
 }
 
 void KGlobalSettingsTest::testFontChange()
 {
     CREATE_ALL_SPYS;
     callClient("-f", SIGNAL(kdisplayFontChanged()));
-#if QT_VERSION <= QT_VERSION_CHECK(5, 0, 0)
-    qDebug() << "The port to Qt5 native event filters broke KXMessages for Qt4, test disabled";
-#else
     QCOMPARE(palette_spy.size(), 0);
     QCOMPARE(font_spy.size(), 1);
     QCOMPARE(style_spy.size(), 0);
     QCOMPARE(settings_spy.size(), 0);
     QCOMPARE(appearance_spy.size(), 1);
-#endif
 }
 
 void KGlobalSettingsTest::testSettingsChange()
 {
     CREATE_ALL_SPYS;
     callClient("--ps", SIGNAL(settingsChanged(int)));
-#if QT_VERSION <= QT_VERSION_CHECK(5, 0, 0)
-    qDebug() << "The port to Qt5 native event filters broke KXMessages for Qt4, test disabled";
-#else
     QCOMPARE(palette_spy.size(), 0);
     QCOMPARE(font_spy.size(), 0);
     QCOMPARE(style_spy.size(), 0);
     QCOMPARE(settings_spy.size(), 1);
     QCOMPARE(settings_spy.at(0).at(0).toInt(), (int)KGlobalSettings::SETTINGS_PATHS);
     QCOMPARE(appearance_spy.size(), 0);
-#endif
 }
